@@ -13,7 +13,9 @@ from bs4 import BeautifulSoup
 
 
 class Badminton():
-    def __init__(self, configpath, max_times=10, begin_time='00:01'):
+    """珠海校区羽毛球场预定脚本
+    """
+    def __init__(self, configpath, begin_time='00:01', max_times=10, token=''):
         self.session = requests.Session()
         self.headers = {
             "Origin": "https://gym.sysu.edu.cn",
@@ -24,18 +26,18 @@ class Badminton():
         self.stocks, self.selects, self.results = [], [], []
         self.capt, self.imbyte = None, None
         self.max_times = max_times
-        self.begin_time = begin_time
+        self.begin_hour = time(int(begin_time.split(':')[0]), int(begin_time.split(':')[1]))
+        self.token = token
 
-        conf_par = configparser.ConfigParser()
         try:
+            conf_par = configparser.ConfigParser()
             conf_par.read(configpath, encoding='utf-8')
             conf = dict(conf_par['badminton'])
+            self.first, self.stock_number = conf['first'], conf['stock_number']
+            self.netid, self.password = conf['netid'], conf['password']
         except KeyError:
             print('检查配置文件是否存在且正确填写')
             sys.exit()
-
-        self.first, self.stock_number = conf['first'], conf['stock_number']
-        self.netid, self.password = conf['netid'], conf['password']
         if (self.netid == '') or (self.password == ''):
             print('填写 netid 和密码')
             sys.exit()
@@ -52,13 +54,13 @@ class Badminton():
             print('检查配置文件填写是否正确')
             sys.exit()
 
-        print(f'预定日期：{self.stock_date}')
-        print(f"预定场次：{conf['stock_name']}\n预定时间：{conf['stock_time']}")
+        print(f'预定日期: {self.stock_date}')
+        print(f"预定场次: {conf['stock_name']}\n预定时间: {conf['stock_time']}")
 
 
     def get_stocks(self):
-        '''获取指定日期可预定的场次列表
-        '''
+        """获取指定日期可预定的场次列表
+        """
         gym_url = 'https://gym.sysu.edu.cn/product/findOkArea.html'
         try_times = 0
         while try_times < self.max_times:
@@ -97,8 +99,8 @@ class Badminton():
 
 
     def select(self):
-        ''' 根据条件筛选场次
-        '''
+        """根据条件筛选场次
+        """
         select = []
         for stock in self.stocks:
             if stock['sname'] in self.stock_name and stock['time_no'] in self.stock_time:
@@ -127,18 +129,23 @@ class Badminton():
 
 
     def recognize(self):
-        ''' 调用某位不知名好心人的在线识别验证码后端
-        '''
-        files = {'img': ('captcha.jpg', self.imbyte, 'image/jpeg')}
+        """调用 http://fast.95man.com 在线识别验证码
+        """
+        headers = {'Connection': 'Keep-Alive',
+                   'User-Agent': 'Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 5.1; Trident/4.0)'}
+        files = {'imgfile': ('captcha.jpg', self.imbyte)}
         recg_times = 0
-        while recg_times < 6:
-            r = requests.post('http://tony-space.top:8989/captcha', files=files)
-            if len(r.text) == 4:
-                self.capt = r.text
-                print(f'验证码识别成功：{self.capt}')
+        while recg_times < self.max_times:
+            r = requests.post(f'http://api.95man.com:8888/api/Http/Recog?Taken={self.token}&imgtype=1&len=4',
+                            files=files, headers=headers)
+            arrstr = r.text.split('|')
+            # 返回格式: 识别ID|识别结果|用户余额
+            if int(arrstr[0]) > 0:
+                print(f'验证码识别成功: {arrstr[1]}')
+                self.capt = arrstr[1]
                 return True
             recg_times += 1
-            print(f'识别失败：{r.text}，第 {recg_times} 次重试')
+            print(f'识别失败: {arrstr[1]}，第 {recg_times} 次重试')
             sleep(1)
             continue
 
@@ -148,6 +155,8 @@ class Badminton():
 
 
     def login(self):
+        """登录
+        """
         headers = {"User-Agent": self.headers['User-Agent']}
         login_url = "https://cas.sysu.edu.cn/cas/login"
         captcha_url = "https://cas.sysu.edu.cn/cas/captcha.jsp"
@@ -194,12 +203,11 @@ class Badminton():
         sys.exit()
 
     def waite(self):
-        ''' 系统正常开启时间为 00:00-22:00，选择合适等待策略
-        '''
+        """系统正常开启时间为 00:00-22:00，选择合适等待策略
+        """
         # 判断预订系统是否开放
         today = date.today()
-        begin_hour = time(7, 0)
-        begin_time = datetime.combine(today, begin_hour)
+        begin_time = datetime.combine(today, self.begin_hour)
         end_time = datetime.combine(today, time(22, 0))
         now_time = datetime.now()
         if now_time < begin_time:
@@ -224,23 +232,23 @@ class Badminton():
                 print('预订日期已经过去，你可以穿越回 22:00 前，再见')
                 sys.exit()
             if stock == 0:
-                begin_time = datetime.combine(self.stock_date, begin_hour)
+                begin_time = datetime.combine(self.stock_date, self.begin_hour)
 
         elif self.stock_date == (today + timedelta(days=1)):
             if stock == 1:
                 print(f'当前时间 {datetime.now()}，开始预订')
                 return True
             if stock == -1:
-                begin_time = datetime.combine(self.stock_date, begin_hour)
+                begin_time = datetime.combine(self.stock_date, self.begin_hour)
                 print('预订系统已关闭')
             elif stock == 0:
                 begin_time = datetime.combine(
-                    self.stock_date - timedelta(days=1), begin_hour)
+                    self.stock_date - timedelta(days=1), self.begin_hour)
 
         elif self.stock_date > (today + timedelta(days=1)):
             # 等到前一天 00:00 才能预订
             begin_time = datetime.combine(
-                self.stock_date - timedelta(days=1), begin_hour)
+                self.stock_date - timedelta(days=1), self.begin_hour)
             print('超过目前可预订日期')
         else:
             print('超出判断条件，你也是个人才')
@@ -345,7 +353,7 @@ class Badminton():
                 print(f'{str(result[0])} 支付成功')
                 self.results.remove(result)
             else:
-                print(f'支付结果：{return_data["message"]}，重试')
+                print(f'支付结果: {return_data["message"]}，重试')
                 sleep(5)
 
         if len(self.results) != 0:
@@ -372,9 +380,15 @@ class Badminton():
 def main():
     parser = argparse.ArgumentParser(description='预定中山大学珠海校区羽毛球场地')
     parser.add_argument('-c', '--config', type=str, help='配置文件路径', required=True)
+    parser.add_argument('-b', '--begin', type=str, help='预定开始时间', default='00:01')
+    parser.add_argument('-m', '--maxtimes', type=int, help='最大预定次数', default=10)
+    parser.add_argument('-t', '--token', type=str,
+                        help='验证码识别平台token', default='Hvfn8AbwxNTySxrnmTknA06onCdb')
     par = parser.parse_args()
-    badminton = Badminton(par.config)
+    badminton = Badminton(par.config, par.begin, par.maxtimes, par.token)
     badminton.run()
 
 if __name__ == '__main__':
     main()
+
+# %%
